@@ -5,7 +5,6 @@ sys.path.append(os.path.join(os.path.dirname(__file__), '../core'))
 from .utils import Color
 from ..core.server import app
 import uvicorn
-print(sys.path)
 color = Color()
 
 class Runner:
@@ -13,5 +12,5 @@ class Runner:
         pass
 
     def run_server(self):
-        print(color.yellow("Start server"))
+        print(color.green("Starting backend server"))
         uvicorn.run(app, host="0.0.0.0", port=8000)
\ No newline at end of file
